@@ -3,6 +3,11 @@ getPImps<-function(ltree,type){
 		return(NULL)
 	if(type==1 && all(ltree$trees$pick==0))
 		return(NULL)
+	if (type == 4 && any(ltree$trees$conc + ltree$trees$pick == 1) || 
+        		any(ltree$trees$knot[ltree$trees$conc == 3] == 0)){
+		return(NULL)
+		warning("Models deleted due to bug in Greedy search in logreg.")
+	}
 	mat.truth<-generateTruthTab(ltree)
 	truth<-ifelse(ltree$coef>=0 | is.na(ltree$coef),1,0)
 	ids.truth<-mat.truth[,"outcome"]==truth
